==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/dialogs/clearerrorsdialog.h <==
#ifndef CLEARERRORSDIALOG_H
#define CLEARERRORSDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "targetabletextsactiondialog.h"
#include <subtitleline.h>

class QCheckBox;
class QPushButton;

namespace SubtitleComposer
{
	class ClearErrorsDialog : public TargetableTextsActionDialog
	{
		Q_OBJECT

		public:

			ClearErrorsDialog( QWidget* parent=0 );

			int errorFlagsToClear();

			bool clearMarks();

		private slots:

			void selectAll();
			void selectNone();

		private:

			QCheckBox* m_errorsCheckBox[SubtitleLine::ErrorSIZE];
			QCheckBox* m_marksCheckBox;
	};
}

#endif

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/dialogs/clearerrorsdialog.h <==
#ifndef CLEARERRORSDIALOG_H
#define CLEARERRORSDIALOG_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include "actionwithtargetdialog.h"
#include <subtitleline.h>

class QCheckBox;
class QPushButton;

namespace SubtitleComposer
{
	class ClearErrorsDialog : public ActionWithTargetDialog
	{
		Q_OBJECT

		public:

			ClearErrorsDialog( QWidget* parent=0 );

			int errorFlagsToClear() const;

			bool clearMarks() const;

		private slots:

			void selectAll();
			void selectNone();

		private:

			QCheckBox* m_errorsCheckBox[SubtitleLine::ErrorSIZE];
			QCheckBox* m_marksCheckBox;
	};
}

#endif
